"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("./config");
const oas3_chow_chow_1 = require("oas3-chow-chow");
const swagger_ui_1 = require("./swagger-ui");
const converter = require("swagger2openapi");
class ValidationError extends Error {
    constructor(message, status, validationErrors) {
        super(message);
        this.status = status;
        this.validationErrors = validationErrors;
    }
}
exports.ValidationError = ValidationError;
async function oas(cfg) {
    const config = config_1.validateConfig(cfg);
    const { compiled, doc } = await compileOas(config.swaggerFile);
    return async (ctx, next) => {
        if (ctx.path === config.swaggerPath) {
            ctx.body = doc;
            return;
        }
        if (ctx.path === config.swaggerUIPath) {
            ctx.body = swagger_ui_1.swaggerUI({
                title: doc.info ? doc.info.title : 'Swagger UI',
                url: config.swaggerPath,
            });
            return;
        }
        if (!config.validatePaths.some(path => ctx.path.startsWith(path))) {
            // Skip validation if no path matches
            return await next();
        }
        compiled.validateRequest(ctx.path, {
            method: ctx.request.method,
            header: ctx.request.header,
            query: ctx.request.query,
            path: ctx.params,
            cookie: ctx.cookies
        });
        await next();
        if (config.validateResponse) {
            //TODO: Adds support to valiadteResponse
            throw new Error('Validate response is under development... :)');
            // const error = swagger.validateResponse(compiledPath, ctx.method, ctx.status, ctx.body);
            // if (error) {
            //   throw new ValidationError(`Response validation failed`, 500, [error]);
            // }
        }
    };
}
exports.oas = oas;
async function compileOas(file) {
    // Convert Swagger to OAS
    const { openapi } = await converter.convertFile(file, {});
    return {
        compiled: new oas3_chow_chow_1.default(openapi),
        doc: openapi,
    };
}
//# sourceMappingURL=index.js.map